Crate abrasive_protocol

Crate abrasive_protocol 

Structs

BuildRequest
DecodeError
FileEntry
Manifest
PlatformTriple

Enums

Abi
Application Binary Interface
Arch
Architecture
Message
Os
Operating System

Functions

deserialize
Deserialize a Message from a bincode payload received over WebSockets.
serialize
Serialize a Message into a bincode payload. WebSocket framing handles length-prefixing for us, so this is just the raw bincode bytes.